@@ -56,7 +56,19 @@ test_virtualenvwrapper_verify_workon_home() {
 test_virtualenvwrapper_verify_workon_home_missing_dir() {
     old_home="$WORKON_HOME"
     WORKON_HOME="$WORKON_HOME/not_there"
-    assertFalse "WORKON_HOME verified unexpectedly" virtualenvwrapper_verify_workon_home
+    assertTrue "Directory already exists" "[ ! -d \"$WORKON_HOME\" ]"
+    virtualenvwrapper_verify_workon_home >"$old_home/output" 2>&1
+    output=$(cat "$old_home/output")
+    assertSame "NOTE: Virtual environments directory $WORKON_HOME does not exist. Creating..." "$output"
+    WORKON_HOME="$old_home"
+}
+
+test_virtualenvwrapper_verify_workon_home_missing_dir_quiet() {
+    old_home="$WORKON_HOME"
+    WORKON_HOME="$WORKON_HOME/not_there_quiet"
+    assertTrue "Directory already exists" "[ ! -d \"$WORKON_HOME\" ]"
+    output=$(virtualenvwrapper_verify_workon_home -q 2>&1)
+    assertSame "" "$output"
     WORKON_HOME="$old_home"
 }
 
@@ -66,19 +78,11 @@ test_virtualenvwrapper_verify_workon_home_missing_dir_grep_options() {
     # This should prevent the message from being found if it isn't
     # unset correctly.
     export GREP_OPTIONS="--count"
-    assertFalse "WORKON_HOME verified unexpectedly" virtualenvwrapper_verify_workon_home
+    assertTrue "WORKON_HOME not verified" virtualenvwrapper_verify_workon_home
     WORKON_HOME="$old_home"
     unset GREP_OPTIONS
 }
 
-test_virtualenvwrapper_verify_workon_home_missing_dir_quiet_init() {
-    old_home="$WORKON_HOME"
-    export WORKON_HOME="$WORKON_HOME/not_there"
-    output=$(source $test_dir/../virtualenvwrapper.sh 2>&1)
-    assertSame "" "$output"
-    WORKON_HOME="$old_home"
-}
-
 test_get_python_version() {
     expected=$(python -V 2>&1 | cut -f2 -d' ' | cut -f-2 -d.)
     actual=$(virtualenvwrapper_get_python_version)
